==> cassandra-driver-core-2.2.0-rc3-sources.jar: com/datastax/driver/core/exceptions/OverloadedException.java <==
/*
 *      Copyright (C) 2012-2015 DataStax Inc.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package com.datastax.driver.core.exceptions;

import java.net.InetSocketAddress;

/**
 * Indicates that the contacted host reported itself being overloaded.
 * This class is mainly intended for internal use;
 * client applications are not expected to deal with this exception directly,
 * because the driver would transparently retry the same query on another host;
 * but such exceptions are likely to appear occasionally in the driver logs.
 */
public class OverloadedException extends DriverInternalError {

    private static final long serialVersionUID = 0;

    private final InetSocketAddress address;

    public OverloadedException(InetSocketAddress address, String message) {
        super(String.format("Queried host (%s) was overloaded: %s", address, message));
        this.address = address;
    }

    /**
     * Private constructor used solely when copying exceptions.
     */
    private OverloadedException(InetSocketAddress address, String message, OverloadedException cause) {
        super(message, cause);
        this.address = address;
    }

    /**
     * The full address of the host that reported itself being overloaded.
     *
     * @return The full address of the host that reported itself being overloaded.
     */
    public InetSocketAddress getAddress() {
        return address;
    }

    @Override
    public OverloadedException copy() {
        return new OverloadedException(address, getMessage(), this);
    }
}

==> cassandra-driver-core-3.0.0-rc1-sources.jar: com/datastax/driver/core/exceptions/OverloadedException.java <==
/*
 *      Copyright (C) 2012-2015 DataStax Inc.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package com.datastax.driver.core.exceptions;

import java.net.InetAddress;
import java.net.InetSocketAddress;

/**
 * Indicates that the contacted host reported itself being overloaded.
 */
public class OverloadedException extends QueryExecutionException implements CoordinatorException {

    private static final long serialVersionUID = 0;

    private final InetSocketAddress address;

    public OverloadedException(InetSocketAddress address, String message) {
        super(String.format("Queried host (%s) was overloaded: %s", address, message));
        this.address = address;
    }

    /**
     * Private constructor used solely when copying exceptions.
     */
    private OverloadedException(InetSocketAddress address, String message, OverloadedException cause) {
        super(message, cause);
        this.address = address;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public InetAddress getHost() {
        return address.getAddress();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public InetSocketAddress getAddress() {
        return address;
    }

    @Override
    public OverloadedException copy() {
        return new OverloadedException(address, getMessage(), this);
    }
}
